==> muitv-0.4.0.tgz: package/src/components/layouts/ConsumptionAuto.js <==
import React, {Component} from "react";

import Grid from "@material-ui/core/Grid";
import Card from "@material-ui/core/Card";
import CardContent from "@material-ui/core/CardContent";
import CardMedia from "@material-ui/core/CardMedia";
import Typography from "@material-ui/core/Typography";
import {withStyles} from "@material-ui/core/styles";

import IconButton from "@material-ui/core/IconButton";
import MoreVertIcon from "@material-ui/icons/MoreVert";

import classNames from "classnames";

const styles = theme => ({

  title: {
    textAlign: 'left'
  },
  subtitle: {
    textAlign: 'left'
  },
  contentCard: {
    marginTop: 'auto'
  },
  cover: {
    maxWidth: '400px',
    maxHeight: '400px',
    width: '100%',
    height: 'auto'
  },
  art: {
//     display: 'inline',
// width: '50%',
// marginRight: '3%',
// verticalAlign: 'bottom'
},


  controls: {

  },
  caption: {
    position: 'absolute',
    marginTop: ".5em"
  },
  left: {
    marginLeft: "1em"
  },
  right: {
    textAlign: 'right',
    right: "1em"
  },

  contentLayout: {
    display: 'flex',
    left: '0px',
    right: '0px',
    marginLeft: '3%',
    marginRight: '3%',
    flexDirection: 'column'
  },
  controlsLayout: {
    position: 'absolute',
    bottom: '10%',
    width: "94%",
    marginRight: "3%",
    marginLeft: "3%"
  }
});

class ConsumptionAuto extends Component {
  constructor(props) {
    super(props);
    this.state = {
      showingSecondButtons: false
    }
  }

  showFirstButtons = () => {
    this.setState({showingSecondButtons: false});
  }

  showSecondButtons = () => {
    this.setState({showingSecondButtons: true});
  }

  adjustThings = () => {
    const $e = document.getElementById.bind(document);
    const content = $e('contentCard');
    const art = $e('artCard');
    const controls = $e('controlsCard');

    // console.log(controls.getBoundingClientRect());
    // console.log(controls.offsetTop, content.offsetHeight);
    content.style.height = controls.offsetTop + "px";

    // content.style.top = (controls.offsetTop - content.offsetHeight) + "px";
    // console.log(getComputedStyle(content).height);

  }

  componentDidMount() {
    this.adjustThings();
    window.addEventListener('resize', this.adjustThings);
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.adjustThings);
  }

  render() {
    const ih = window.innerHeight;
    const iw = window.innerWidth;
    const {
      classes,
      buttonClasses,
      firstActionButtons = [],
      progress,
      title,
      subtitle,
      secondActionButtons = [],
      leftValue,
      rightValue,
      art,
      artSize
    } = this.props;

    const {showingSecondButtons} = this.state;

    const buttonClass = ih > 700
      ? buttonClasses.button3
      : ih > 395
        ? buttonClasses.button2
        : buttonClasses.button1;
    const iconClass = ih > 700
      ? buttonClasses.icon3
      : ih > 395
        ? buttonClasses.icon2
        : buttonClasses.icon1;

    const firstMoreButton = <IconButton className={buttonClass} aria-label="Toggle" onClick={this.showSecondButtons}>
      <MoreVertIcon className={iconClass}/>
    </IconButton>;

    const secondMoreButton = <IconButton className={buttonClass} aria-label="Toggle" onClick={this.showFirstButtons}>
      <MoreVertIcon className={iconClass}/>
    </IconButton>;

    // TODO: add the toggle for each
    const firstButtons = firstActionButtons.concat(firstMoreButton);
    const secondButtons = secondActionButtons.concat(secondMoreButton);
    const buttons = showingSecondButtons
      ? secondButtons
      : firstButtons;
/*
<CardMedia
  className={classes.cover}
  image={art}
/>*/
    const contentCard = (<Card className={classes.contentCard}>
      <Typography variant="title" className={classes.title}>
        {title}
      </Typography>
      <Typography variant="subheading" className={classes.subtitle}>
        {subtitle}
      </Typography>
    </Card>);

    const controlsCard = (<Card className={classes.controls}>
      {progress}
      <Typography variant="caption" className={classNames(classes.left, classes.caption)}>
        {leftValue}
      </Typography>
      <Typography variant="caption" className={classNames(classes.right, classes.caption)}>
        {rightValue}
      </Typography>
      <div className={classes.controls}>
        {
          buttons.map((b, i) => {
            return <React.Fragment key={i}>{b}</React.Fragment>;
          })
        }
      </div>
    </Card>);
    return (<div>
      <div id='contentCard' className={classes.contentLayout}>
        {contentCard}
      </div>
      <div id='controlsCard' className={classes.controlsLayout}>
        {controlsCard}
      </div>
    </div>);
  }
}

export default withStyles(styles)(ConsumptionAuto);

==> muitv-0.6.1.tgz: package/src/components/layouts/ConsumptionAuto.js <==
import React, {Component} from "react";

import Grid from "@material-ui/core/Grid";
import Card from "@material-ui/core/Card";
import CardContent from "@material-ui/core/CardContent";
import CardMedia from "@material-ui/core/CardMedia";
import Typography from "@material-ui/core/Typography";
import {withStyles} from "@material-ui/core/styles";

import IconButton from "@material-ui/core/IconButton";
import MoreVertIcon from "@material-ui/icons/MoreVert";

import classNames from "classnames";

const styles = theme => ({

  title: {
    textAlign: 'left'
  },
  subtitle: {
    textAlign: 'left'
  },
  contentCard: {
    marginTop: 'auto'
  },
  cover: {
    maxWidth: '400px',
    maxHeight: '400px',
    width: '100%',
    height: 'auto'
  },
  art: {
//     display: 'inline',
// width: '50%',
// marginRight: '3%',
// verticalAlign: 'bottom'
},


  controls: {

  },
  caption: {
    position: 'absolute',
    marginTop: ".5em"
  },
  left: {
    marginLeft: "1em"
  },
  right: {
    textAlign: 'right',
    right: "1em"
  },

  contentLayout: {
    display: 'flex',
    left: '0px',
    right: '0px',
    marginLeft: '3%',
    marginRight: '3%',
    flexDirection: 'column'
  },
  controlsLayout: {
    position: 'absolute',
    bottom: '10%',
    width: "94%",
    marginRight: "3%",
    marginLeft: "3%"
  }
});

class ConsumptionAuto extends Component {
  constructor(props) {
    super(props);
    this.state = {
      showingSecondButtons: false
    }
  }

  showFirstButtons = () => {
    this.setState({showingSecondButtons: false});
  }

  showSecondButtons = () => {
    this.setState({showingSecondButtons: true});
  }

  adjustThings = () => {
    const $e = document.getElementById.bind(document);
    const content = $e('contentCard');
    const art = $e('artCard');
    const controls = $e('controlsCard');

    // console.log(controls.getBoundingClientRect());
    // console.log(controls.offsetTop, content.offsetHeight);
    content.style.height = controls.offsetTop + "px";

    // content.style.top = (controls.offsetTop - content.offsetHeight) + "px";
    // console.log(getComputedStyle(content).height);

  }

  componentDidMount() {
    this.adjustThings();
    window.addEventListener('resize', this.adjustThings);
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.adjustThings);
  }

  render() {
    const ih = window.innerHeight;
    const iw = window.innerWidth;
    const {
      classes,
      buttonClasses,
      firstActionButtons = [],
      progress,
      title,
      subtitle,
      secondActionButtons = [],
      leftValue,
      rightValue,
      art,
      artSize
    } = this.props;

    const {showingSecondButtons} = this.state;

    const buttonClass = ih > 700
      ? buttonClasses.button3
      : ih > 395
        ? buttonClasses.button2
        : buttonClasses.button1;
    const iconClass = ih > 700
      ? buttonClasses.icon3
      : ih > 395
        ? buttonClasses.icon2
        : buttonClasses.icon1;

    const firstMoreButton = <IconButton className={buttonClass} aria-label="Toggle" onClick={this.showSecondButtons}>
      <MoreVertIcon className={iconClass}/>
    </IconButton>;

    const secondMoreButton = <IconButton className={buttonClass} aria-label="Toggle" onClick={this.showFirstButtons}>
      <MoreVertIcon className={iconClass}/>
    </IconButton>;

    // TODO: add the toggle for each
    const firstButtons = firstActionButtons.concat(firstMoreButton);
    const secondButtons = secondActionButtons.concat(secondMoreButton);
    const buttons = showingSecondButtons
      ? secondButtons
      : firstButtons;
/*
<CardMedia
  className={classes.cover}
  image={art}
/>*/
    const contentCard = (<Card className={classes.contentCard}>
      <Typography variant="h6" className={classes.title}>
        {title}
      </Typography>
      <Typography variant="subtitle1" className={classes.subtitle}>
        {subtitle}
      </Typography>
    </Card>);

    const controlsCard = (<Card className={classes.controls}>
      {progress}
      <Typography variant="caption" className={classNames(classes.left, classes.caption)}>
        {leftValue}
      </Typography>
      <Typography variant="caption" className={classNames(classes.right, classes.caption)}>
        {rightValue}
      </Typography>
      <div className={classes.controls}>
        {
          buttons.map((b, i) => {
            return <React.Fragment key={i}>{b}</React.Fragment>;
          })
        }
      </div>
    </Card>);
    return (<div>
      <div id='contentCard' className={classes.contentLayout}>
        {contentCard}
      </div>
      <div id='controlsCard' className={classes.controlsLayout}>
        {controlsCard}
      </div>
    </div>);
  }
}

export default withStyles(styles)(ConsumptionAuto);
